about summary refs log tree commit diff
path: root/tools/emacs/config/init.el
diff options
context:
space:
mode:
Diffstat (limited to 'tools/emacs/config/init.el')
-rw-r--r--tools/emacs/config/init.el11
1 files changed, 6 insertions, 5 deletions
diff --git a/tools/emacs/config/init.el b/tools/emacs/config/init.el
index a23a16fca5..83621a99f9 100644
--- a/tools/emacs/config/init.el
+++ b/tools/emacs/config/init.el
@@ -170,10 +170,11 @@
 (telephone-line-setup)
 (ace-window-display-mode)
 
-;; If a local configuration file exists, it should be loaded. No
-;; other configuration comes from `user-emacs-directory'.
-(let ((local-file (expand-file-name (f-join user-emacs-directory "local.el"))))
-  (when (f-exists? local-file)
-    (load local-file)))
+;; If a local configuration library exists, it should be loaded.
+;;
+;; This can be provided by calling my Emacs derivation with
+;; `withLocalConfig'.
+(if-let (local-file (locate-library "local"))
+    (load local-file))
 
 (provide 'init)